@@ -1,6 +1,6 @@
 package WebService::ThrowAwayMail;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moo;
 use MooX::LazierAttributes qw/rw lzy/;
@@ -17,11 +17,11 @@ attributes (
 
 validate_subs ( 
     get_alias => { params => [], returns => [[Str]] },
-    get => { params => [], returns => [[HashRef]] },
+    get => { params => [ [Str, 'base_url'] ], returns => [[HashRef]] },
 );
 
 sub get {
-    my $response = $_[0]->tiny->get($_[0]->base_url);
+    my $response = $_[0]->tiny->get($_[1]);
     $response->{success} and return $response;
     croak sprintf "something went terribly wrong status - %s - reason - %s", 
         $response->{status}, $response->{reason};
@@ -41,7 +41,7 @@ WebService::ThrowAwayMail - Perl client for throwawaymail.org API
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
